#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "freertos/queue.h"

#include "driver/gpio.h"

#include "esp_log.h"
#include "esp_system.h"
#include "esp_spi_flash.h"
#include "oledfont.h"

#define OLED_CMD  0	//写命令
#define OLED_DATA 1	//写数据
#define u8 unsigned char
#define u32 unsigned int

u8 OLED_GRAM[144][8];
//-----------------OLED端口定义             VCC  3.3v电源
//              D0     13（SCL）
//              D1     12（SDA） 
//              RES  14
//              DC    16
//              CS     15  
#define GPIO_OLED_SCLK_Port    GPIO_Pin_13
#define GPIO_OLED_SCLK 				GPIO_NUM_13

#define GPIO_OLED_SDIN_Port     GPIO_Pin_12
#define GPIO_OLED_SDIN 			   GPIO_NUM_12

#define GPIO_OLED_RST_Port    GPIO_Pin_14
#define GPIO_OLED_RST 				GPIO_NUM_14

#define GPIO_OLED_DC_Port     GPIO_Pin_16
#define GPIO_OLED_DC 			   GPIO_NUM_16

#define GPIO_OLED_CS_Port    GPIO_Pin_15
#define GPIO_OLED_CS 				GPIO_NUM_15
//*********************************ADT7320温度传感器引脚*************3.3V电源
//				DIN					5
//				SCL					4
//				CS					 0
//				DOUT			2
#define GPIO_ADT7320_DIN_Port	GPIO_Pin_0
#define GPIO_ADT7320_DIN				GPIO_NUM_0

#define GPOI_ADT7320_SCL_Port	GPIO_Pin_5
#define GPOI_ADT7320_SCL				GPIO_NUM_5

#define GPOI_ADT7320_CS_Port	GPIO_Pin_4
#define GPOI_ADT7320_CS					GPIO_NUM_4

#define GPOI_ADT7320_DOUT_Port	GPIO_Pin_2
#define GPOI_ADT7320_DOUT			GPIO_NUM_2
//*************************************************引脚综合
#define GPIO_OLED_OUTPUT_IO_NUM (GPIO_OLED_SCLK_Port | GPIO_OLED_SDIN_Port | GPIO_OLED_RST_Port | GPIO_OLED_DC_Port | GPIO_OLED_CS_Port )
#define GPIO_ADT7320_OUTPUT_IO_NUM (GPIO_ADT7320_DIN_Port | GPOI_ADT7320_SCL_Port | GPOI_ADT7320_CS_Port)
#define GPIO_ADT7320_INPUT_IO_NUM GPOI_ADT7320_DOUT_Port
//*****************************************************************OLED
#define OLED_SCLK_Clr() gpio_set_level(GPIO_OLED_SCLK,0)//SCL
#define OLED_SCLK_Set() gpio_set_level(GPIO_OLED_SCLK,1)

#define OLED_SDIN_Clr() gpio_set_level(GPIO_OLED_SDIN,0)//DIN
#define OLED_SDIN_Set() gpio_set_level(GPIO_OLED_SDIN,1)

#define OLED_RST_Clr() gpio_set_level(GPIO_OLED_RST,0)//RES
#define OLED_RST_Set() gpio_set_level(GPIO_OLED_RST,1)

#define OLED_DC_Clr() gpio_set_level(GPIO_OLED_DC,0)//DC
#define OLED_DC_Set() gpio_set_level(GPIO_OLED_DC,1)
 		     
#define OLED_CS_Clr()  gpio_set_level(GPIO_OLED_CS,0)//CS
#define OLED_CS_Set()  gpio_set_level(GPIO_OLED_CS,1)

//***********************************************************ADT7320
// add the header file here
#define	DIN_0		  gpio_set_level(GPIO_ADT7320_DIN, 0)//O
#define	DIN_1		  gpio_set_level(GPIO_ADT7320_DIN, 1)//O

#define	SCL_0		  gpio_set_level(GPOI_ADT7320_SCL, 0)//O
#define	SCL_1		  gpio_set_level(GPOI_ADT7320_SCL, 1)//O

#define	CS_0		  gpio_set_level(GPOI_ADT7320_CS, 0)//O
#define	CS_1		  gpio_set_level(GPOI_ADT7320_CS, 1)//O

#define	DOUT		gpio_get_level(GPOI_ADT7320_DOUT)//I
//**************************************************************OLED模块
void OLED_ClearPoint(u8 x,u8 y);
void OLED_ColorTurn(u8 i);
void OLED_DisplayTurn(u8 i);
void OLED_WR_Byte(u8 dat,u8 cmd);
void OLED_DisPlay_On(void);
void OLED_DisPlay_Off(void);
void OLED_Refresh(void);
void OLED_Clear(void);
void OLED_DrawPoint(u8 x,u8 y);
void OLED_DrawLine(u8 x1,u8 y1,u8 x2,u8 y2);
void OLED_DrawCircle(u8 x,u8 y,u8 r);
void OLED_ShowChar(u8 x,u8 y,u8 chr,u8 size1);
void OLED_ShowString(u8 x,u8 y,u8 *chr,u8 size1);
void OLED_ShowNum(u8 x,u8 y,u32 num,u8 len,u8 size1);
void OLED_ShowChinese(u8 x,u8 y,u8 num,u8 size1);
void OLED_ScrollDisplay(u8 num,u8 space);
void OLED_WR_BP(u8 x,u8 y);
void OLED_ShowPicture(u8 x0,u8 y0,u8 x1,u8 y1,u8 BMP[]);
static void OLED_Init(void);
//*********************************************************************************ADT7320温度传感器
unsigned int ReadFromADT7320ViaSPI(unsigned int reg_address, unsigned int Bit);
void WriteToADT7320ViaSPI(unsigned int reg_address, unsigned int reg_data, unsigned int Bit);
//*******************************************************************************************************************主函数
void app_main(void)
{
    gpio_config_t io_conf;
    //disable interrupt
    io_conf.intr_type = GPIO_INTR_DISABLE;
    //set as output mode
    io_conf.mode = GPIO_MODE_OUTPUT;
    //bit mask of the pins that you want to set,e.g.GPIO15/16
    io_conf.pin_bit_mask = GPIO_OLED_OUTPUT_IO_NUM | GPIO_ADT7320_OUTPUT_IO_NUM;
    //disable pull-down mode
    io_conf.pull_down_en = 0;
    //disable pull-up mode
    io_conf.pull_up_en = 1;
    //configure GPIO with the given settings
    gpio_config(&io_conf);

    //interrupt of rising edge
    io_conf.intr_type = GPIO_INTR_POSEDGE;
    //bit mask of the pins, use GPIO4/5 here
    io_conf.pin_bit_mask = GPIO_ADT7320_INPUT_IO_NUM;
    //set as input mode
    io_conf.mode = GPIO_MODE_INPUT;
    //enable pull-up mode
    io_conf.pull_up_en = 1;
    gpio_config(&io_conf);

    gpio_set_level(GPIO_OLED_SCLK, 1);
    gpio_set_level(GPIO_OLED_SDIN, 1);
    gpio_set_level(GPIO_OLED_RST, 1);
    gpio_set_level(GPIO_OLED_CS, 1);
    gpio_set_level(GPIO_OLED_DC, 1);

	OLED_Init();
	OLED_ColorTurn(0);//0正常显示，1 反色显示
	OLED_DisplayTurn(0);//0正常显示 1 屏幕翻转显示
	OLED_Refresh();

	// OLED_ShowChinese(0,0,0,16);//中
	// OLED_ShowChinese(18,0,1,16);//景
	// OLED_ShowChinese(36,0,2,16);//园
	// OLED_ShowChinese(54,0,3,16);//电
	// OLED_ShowChinese(72,0,4,16);//子
	// OLED_ShowChinese(90,0,5,16);//科
	// OLED_ShowChinese(108,0,6,16);//技
	OLED_ShowString(0,0,(u8 *)"Target",16);
	OLED_ShowString(0,16,(u8 *)"Temperature:",16);
	OLED_ShowString(36,32,(u8 *)".",24);  
	OLED_ShowString(72,32,(u8 *)"'C",24);  
	OLED_Refresh();

	WriteToADT7320ViaSPI(0x01,0x80,8);
    int cnt = 0;
	int value = 0;
	int Tmp;
    while (1) {
		cnt++;

        //   OLED_ShowString(63,48,(u8 *)"CODE:",16);
		// WriteToADT7320ViaSPI(0x01,0x80,8);
		vTaskDelay(500/ portTICK_RATE_MS);
		value = ReadFromADT7320ViaSPI(0x02,16);
		vTaskDelay(500/ portTICK_RATE_MS);		
		Tmp=(int)((value)*0.78);
		// OLED_ShowNum(0,32,value,5,24);
		OLED_ShowNum(0,32,(Tmp / 100),3,24);
		OLED_ShowNum(48,32,(Tmp % 100),2,24);
		OLED_Refresh();
		printf("%d\n",value);
		printf("%d\n",cnt);
		if (cnt > 500)
        {
          cnt = 0;
        }
    }
}
//************************************************************************************************************************************************************
//反显函数
void OLED_ColorTurn(u8 i)
{
	if(i==0)
		{
			OLED_WR_Byte(0xA6,OLED_CMD);//正常显示
		}
	if(i==1)
		{
			OLED_WR_Byte(0xA7,OLED_CMD);//反色显示
		}
}

//屏幕旋转180度
void OLED_DisplayTurn(u8 i)
{
	if(i==0)
		{
			OLED_WR_Byte(0xC8,OLED_CMD);//正常显示
			OLED_WR_Byte(0xA1,OLED_CMD);
		}
	if(i==1)
		{
			OLED_WR_Byte(0xC0,OLED_CMD);//反转显示
			OLED_WR_Byte(0xA0,OLED_CMD);
		}
}


void OLED_WR_Byte(u8 dat,u8 cmd)
{	
	u8 i;			  
	if(cmd)
	  OLED_DC_Set();
	else
	  OLED_DC_Clr();
	OLED_CS_Clr();
	for(i=0;i<8;i++)
	{
		OLED_SCLK_Clr();
		if(dat&0x80)
		   OLED_SDIN_Set();
		else 
		   OLED_SDIN_Clr();
		OLED_SCLK_Set();
		dat<<=1;   
	}				 		  
	OLED_CS_Set();
	OLED_DC_Set();   	  
}

//开启OLED显示 
void OLED_DisPlay_On(void)
{
	OLED_WR_Byte(0x8D,OLED_CMD);//电荷泵使能
	OLED_WR_Byte(0x14,OLED_CMD);//开启电荷泵
	OLED_WR_Byte(0xAF,OLED_CMD);//点亮屏幕
}

//关闭OLED显示 
void OLED_DisPlay_Off(void)
{
	OLED_WR_Byte(0x8D,OLED_CMD);//电荷泵使能
	OLED_WR_Byte(0x10,OLED_CMD);//关闭电荷泵
	OLED_WR_Byte(0xAF,OLED_CMD);//关闭屏幕
}

//更新显存到OLED	
void OLED_Refresh(void)
{
	u8 i,n;
	for(i=0;i<8;i++)
	{
	   OLED_WR_Byte(0xb0+i,OLED_CMD); //设置行起始地址
	   OLED_WR_Byte(0x00,OLED_CMD);   //设置低列起始地址
	   OLED_WR_Byte(0x10,OLED_CMD);   //设置高列起始地址
	   for(n=0;n<128;n++)
		 OLED_WR_Byte(OLED_GRAM[n][i],OLED_DATA);
  }
}
//清屏函数
void OLED_Clear(void)
{
	u8 i,n;
	for(i=0;i<8;i++)
	{
	   for(n=0;n<128;n++)
			{
			 OLED_GRAM[n][i]=0;//清除所有数据
			}
  }
	OLED_Refresh();//更新显示
}

//画点 
//x:0~127
//y:0~63
void OLED_DrawPoint(u8 x,u8 y)
{
	u8 i,m,n;
	i=y/8;
	m=y%8;
	n=1<<m;
	OLED_GRAM[x][i]|=n;
}

//清除一个点
//x:0~127
//y:0~63
void OLED_ClearPoint(u8 x,u8 y)
{
	u8 i,m,n;
	i=y/8;
	m=y%8;
	n=1<<m;
	OLED_GRAM[x][i]=~OLED_GRAM[x][i];
	OLED_GRAM[x][i]|=n;
	OLED_GRAM[x][i]=~OLED_GRAM[x][i];
}


//画线
//x:0~128
//y:0~64
void OLED_DrawLine(u8 x1,u8 y1,u8 x2,u8 y2)
{
	u8 i,k,k1,k2;
	if((x1<0)||(x2>128)||(y1<0)||(y2>64)||(x1>x2)||(y1>y2))return;
	if(x1==x2)    //画竖线
	{
			for(i=0;i<(y2-y1);i++)
			{
				OLED_DrawPoint(x1,y1+i);
			}
  }
	else if(y1==y2)   //画横线
	{
			for(i=0;i<(x2-x1);i++)
			{
				OLED_DrawPoint(x1+i,y1);
			}
  }
	else      //画斜线
	{
		k1=y2-y1;
		k2=x2-x1;
		k=k1*10/k2;
		for(i=0;i<(x2-x1);i++)
			{
			  OLED_DrawPoint(x1+i,y1+i*k/10);
			}
	}
}
//x,y:圆心坐标
//r:圆的半径
void OLED_DrawCircle(u8 x,u8 y,u8 r)
{
	int a, b,num;
    a = 0;
    b = r;
    while(2 * b * b >= r * r)      
    {
        OLED_DrawPoint(x + a, y - b);
        OLED_DrawPoint(x - a, y - b);
        OLED_DrawPoint(x - a, y + b);
        OLED_DrawPoint(x + a, y + b);
 
        OLED_DrawPoint(x + b, y + a);
        OLED_DrawPoint(x + b, y - a);
        OLED_DrawPoint(x - b, y - a);
        OLED_DrawPoint(x - b, y + a);
        
        a++;
        num = (a * a + b * b) - r*r;//计算画的点离圆心的距离
        if(num > 0)
        {
            b--;
            a--;
        }
    }
}



//在指定位置显示一个字符,包括部分字符
//x:0~127
//y:0~63
//size:选择字体 12/16/24
//取模方式 逐列式
void OLED_ShowChar(u8 x,u8 y,u8 chr,u8 size1)
{
	u8 i,m,temp,size2,chr1;
	u8 y0=y;
	size2=(size1/8+((size1%8)?1:0))*(size1/2);  //得到字体一个字符对应点阵集所占的字节数
	chr1=chr-' ';  //计算偏移后的值
	for(i=0;i<size2;i++)
	{
		if(size1==12)
        {temp=asc2_1206[chr1][i];} //调用1206字体
		else if(size1==16)
        {temp=asc2_1608[chr1][i];} //调用1608字体
		else if(size1==24)
        {temp=asc2_2412[chr1][i];} //调用2412字体
		else return;
				for(m=0;m<8;m++)           //写入数据
				{
					if(temp&0x80)OLED_DrawPoint(x,y);
					else OLED_ClearPoint(x,y);
					temp<<=1;
					y++;
					if((y-y0)==size1)
					{
						y=y0;
						x++;
						break;
          }
				}
  }
}


//显示字符串
//x,y:起点坐标  
//size1:字体大小 
//*chr:字符串起始地址 
void OLED_ShowString(u8 x,u8 y,u8 *chr,u8 size1)
{
	while((*chr>=' ')&&(*chr<='~'))//判断是不是非法字符!
	{
		OLED_ShowChar(x,y,*chr,size1);
		x+=size1/2;
		if(x>128-size1)  //换行
		{
			x=0;
			y+=2;
    }
		chr++;
  }
}

//m^n
u32 OLED_Pow(u8 m,u8 n)
{
	u32 result=1;
	while(n--)
	{
	  result*=m;
	}
	return result;
}

////显示2个数字
////x,y :起点坐标	 
////len :数字的位数
////size:字体大小
void OLED_ShowNum(u8 x,u8 y,u32 num,u8 len,u8 size1)
{
	u8 t,temp;
	for(t=0;t<len;t++)
	{
		temp=(num/OLED_Pow(10,len-t-1))%10;
			if(temp==0)
			{
				OLED_ShowChar(x+(size1/2)*t,y,'0',size1);
      }
			else 
			{
			  OLED_ShowChar(x+(size1/2)*t,y,temp+'0',size1);
			}
  }
}

//显示汉字
//x,y:起点坐标
//num:汉字对应的序号
//取模方式 列行式
void OLED_ShowChinese(u8 x,u8 y,u8 num,u8 size1)
{
	u8 i,m,n=0,temp,chr1;
	u8 x0=x,y0=y;
	u8 size3=size1/8;
	while(size3--)
	{
		chr1=num*size1/8+n;
		n++;
			for(i=0;i<size1;i++)
			{
				if(size1==16)
						{temp=Hzk1[chr1][i];}//调用16*16字体
				else if(size1==24)
						{temp=Hzk2[chr1][i];}//调用24*24字体
				else if(size1==32)       
						{temp=Hzk3[chr1][i];}//调用32*32字体
				else if(size1==64)
						{temp=Hzk4[chr1][i];}//调用64*64字体
				else return;
							
						for(m=0;m<8;m++)
							{
								if(temp&0x01)OLED_DrawPoint(x,y);
								else OLED_ClearPoint(x,y);
								temp>>=1;
								y++;
							}
							x++;
							if((x-x0)==size1)
							{x=x0;y0=y0+8;}
							y=y0;
			 }
	}
}

//num 显示汉字的个数
//space 每一遍显示的间隔
void OLED_ScrollDisplay(u8 num,u8 space)
{
	u8 i,n,t=0,m=0,r;
	while(1)
	{
		if(m==0)
		{
	    OLED_ShowChinese(128,24,t,16); //写入一个汉字保存在OLED_GRAM[][]数组中
			t++;
		}
		if(t==num)
			{
				for(r=0;r<16*space;r++)      //显示间隔
				 {
					for(i=0;i<144;i++)
						{
							for(n=0;n<8;n++)
							{
								OLED_GRAM[i-1][n]=OLED_GRAM[i][n];
							}
						}
           OLED_Refresh();
				 }
        t=0;
      }
		m++;
		if(m==16){m=0;}
		for(i=0;i<144;i++)   //实现左移
		{
			for(n=0;n<8;n++)
			{
				OLED_GRAM[i-1][n]=OLED_GRAM[i][n];
			}
		}
		OLED_Refresh();
	}
}

//配置写入数据的起始位置
void OLED_WR_BP(u8 x,u8 y)
{
	OLED_WR_Byte(0xb0+y,OLED_CMD);//设置行起始地址
	OLED_WR_Byte(((x&0xf0)>>4)|0x10,OLED_CMD);
	OLED_WR_Byte((x&0x0f),OLED_CMD);
}

//x0,y0：起点坐标
//x1,y1：终点坐标
//BMP[]：要写入的图片数组
void OLED_ShowPicture(u8 x0,u8 y0,u8 x1,u8 y1,u8 BMP[])
{
	u32 j=0;
	u8 x=0,y=0;
	if(y%8==0)y=0;
	else y+=1;
	for(y=y0;y<y1;y++)
	 {
		 OLED_WR_BP(x0,y);
		 for(x=x0;x<x1;x++)
		 {
			 OLED_WR_Byte(BMP[j],OLED_DATA);
			 j++;
     }
	 }
}
//OLED的初始化
static void OLED_Init(void)
{
	OLED_RST_Clr();//复位
	// vTaskDelay(200 / portTICK_RATE_MS);
  	printf("1234567890\r\n");
	OLED_RST_Set();
	
	OLED_WR_Byte(0xAE,OLED_CMD);//--turn off oled panel
	OLED_WR_Byte(0x00,OLED_CMD);//---set low column address
	OLED_WR_Byte(0x10,OLED_CMD);//---set high column address
	OLED_WR_Byte(0x40,OLED_CMD);//--set start line address  Set Mapping RAM Display Start Line (0x00~0x3F)
	OLED_WR_Byte(0x81,OLED_CMD);//--set contrast control register
	OLED_WR_Byte(0xCF,OLED_CMD);// Set SEG Output Current Brightness
	OLED_WR_Byte(0xA1,OLED_CMD);//--Set SEG/Column Mapping     0xa0左右反置 0xa1正常
	OLED_WR_Byte(0xC8,OLED_CMD);//Set COM/Row Scan Direction   0xc0上下反置 0xc8正常
	OLED_WR_Byte(0xA6,OLED_CMD);//--set normal display
	OLED_WR_Byte(0xA8,OLED_CMD);//--set multiplex ratio(1 to 64)
	OLED_WR_Byte(0x3f,OLED_CMD);//--1/64 duty
	OLED_WR_Byte(0xD3,OLED_CMD);//-set display offset	Shift Mapping RAM Counter (0x00~0x3F)
	OLED_WR_Byte(0x00,OLED_CMD);//-not offset
	OLED_WR_Byte(0xd5,OLED_CMD);//--set display clock divide ratio/oscillator frequency
	OLED_WR_Byte(0x80,OLED_CMD);//--set divide ratio, Set Clock as 100 Frames/Sec
	OLED_WR_Byte(0xD9,OLED_CMD);//--set pre-charge period
	OLED_WR_Byte(0xF1,OLED_CMD);//Set Pre-Charge as 15 Clocks & Discharge as 1 Clock
	OLED_WR_Byte(0xDA,OLED_CMD);//--set com pins hardware configuration
	OLED_WR_Byte(0x12,OLED_CMD);
	OLED_WR_Byte(0xDB,OLED_CMD);//--set vcomh
	OLED_WR_Byte(0x40,OLED_CMD);//Set VCOM Deselect Level
	OLED_WR_Byte(0x20,OLED_CMD);//-Set Page Addressing Mode (0x00/0x01/0x02)
	OLED_WR_Byte(0x02,OLED_CMD);//
	OLED_WR_Byte(0x8D,OLED_CMD);//--set Charge Pump enable/disable
	OLED_WR_Byte(0x14,OLED_CMD);//--set(0x10) disable
	OLED_WR_Byte(0xA4,OLED_CMD);// Disable Entire Display On (0xa4/0xa5)
	OLED_WR_Byte(0xA6,OLED_CMD);// Disable Inverse Display On (0xa6/a7) 
	OLED_WR_Byte(0xAF,OLED_CMD);
	OLED_Clear();
}

/********************************************************************************
 Function: 	 ReadFromADT7320ViaSPI
 Parameter:  none
 Return value :	 unsigned int
 Description :	Configure the regisiters of ADT7320, and read the convention data. 
********************************************************************************/
unsigned int ReadFromADT7320ViaSPI(unsigned int reg_address, unsigned int Bit)
{
	unsigned int   i;
	unsigned int misoValue = 0;
	unsigned int spi_Value;	
	//unsigned int flag;
	spi_Value = (0x40 | ( 0x78 & (reg_address << 3)));
	
	//flag = spi_Value;
	CS_1;//ADuC7026OutputBit(CS,1);	 
	SCL_1;//ADuC7026OutputBit(SCL,1);   
	CS_0;//ADuC7026OutputBit(CS,0);
	vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(5);
  
	for(i=0;i<8;i++)  
	{  
   	SCL_0	;//ADuC7026OutputBit(SCL,0); 
   		if(spi_Value & 0x80) 
     		DIN_1;//ADuC7026OutputBit(DIN,1);  
   		else  
     		DIN_0;//ADuC7026OutputBit(DIN,0); 
   		vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(5);
		SCL_1;//ADuC7026OutputBit(SCL,1);   		
   		spi_Value = (spi_Value << 1);  
		vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(5);
	}
	DIN_1;
  //ADuC7026Delay(50);	
	for(i=0;i<Bit;i++)  
	{  
   	SCL_0;//ADuC7026OutputBit(SCL,0); 
  	misoValue = (misoValue << 1);
		vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(10);
		if((DOUT) == 1)  
         	misoValue |= 0x0001;  
    else  {
		misoValue &= 0xfffe;
	}
         	
   		vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(2);
		SCL_1;//ADuC7026OutputBit(SCL,1);  
		
		vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(8);
	} 
	SCL_1;//ADuC7026OutputBit(SCL,1);
	CS_1;//ADuC7026OutputBit(CS,1);
	return  misoValue; 
}

/********************************************************************************
 Function: 	 WriteToADT7320ViaSPI
 Parameter:  unsigned char spi_mosiValue
 Return value :	 none
 Description :	Configure the regisiters of ADT7320, and read the convention data. 
********************************************************************************/
void WriteToADT7320ViaSPI(unsigned int reg_address, unsigned int reg_data, unsigned int Bit)
{
	unsigned int   i;
	unsigned int spi_Value;
	unsigned int spi_Value_data;
	spi_Value = ( 0x78 & (reg_address << 3));
	spi_Value_data = reg_data;
	
	CS_1;//ADuC7026OutputBit(CS,1);	 
	SCL_1;//ADuC7026OutputBit(SCL,1);   
	CS_0;//ADuC7026OutputBit(CS,0);  

	for(i=0;i<8;i++)  
	{  
   	SCL_0;//ADuC7026OutputBit(SCL,0); 
   		if(spi_Value & 0x80) 
     		DIN_1;//ADuC7026OutputBit(DIN,1);  
   		else  
     		DIN_0;//ADuC7026OutputBit(DIN,0); 
		vTaskDelay(2/ portTICK_RATE_MS);//   		HAL_Delay(2);
		SCL_1;//ADuC7026OutputBit(SCL,1);    		
   	spi_Value = (spi_Value << 1);  		
		vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(5);
	}
	
	if(Bit == 8)
	{
		for(i=0;i<Bit;i++)  
		{  
				SCL_0;//ADuC7026OutputBit(SCL,0); 
				if((spi_Value_data & 0x80)==0x80)  
					DIN_1;//ADuC7026OutputBit(DIN,1);  
				else  
					DIN_0;//ADuC7026OutputBit(DIN,0); 
				vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(2);
			SCL_1;//ADuC7026OutputBit(SCL,1);  
			spi_Value_data = (spi_Value_data << 1);  
			vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(5);
		}
	}else{
		for(i=0;i<Bit;i++)  
		{  
				SCL_0;//ADuC7026OutputBit(SCL,0); 
				if(spi_Value_data & 0x8000) 
					DIN_1;//ADuC7026OutputBit(DIN,1);  
				else  
					DIN_0;//ADuC7026OutputBit(DIN,0); 
				vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(2);
			SCL_1;//ADuC7026OutputBit(SCL,1);  
			spi_Value_data = (spi_Value_data << 1);  
			vTaskDelay(2/ portTICK_RATE_MS);//HAL_Delay(5);
		}
	}
	SCL_1;//ADuC7026OutputBit(SCL,1);
	CS_1;//ADuC7026OutputBit(CS,1);
}

